aboutsummaryrefslogtreecommitdiff
path: root/object/id/errors.go
diff options
context:
space:
mode:
authorGravatar Runxi Yu2026-05-24 11:07:16 +0000
committerGravatar Runxi Yu2026-05-24 11:09:59 +0000
commit36340918040627d93808c09dea8d9bd7b7457f82 (patch)
treedab5fa0edbf2f2bf315d1fda73c0f7ac5c8fc6d9 /object/id/errors.go
parentinternal/testgit: Add Algorithm method (diff)
signatureNo signature
object/id: Rename algorithm to object format
Diffstat (limited to 'object/id/errors.go')
-rw-r--r--object/id/errors.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/object/id/errors.go b/object/id/errors.go
index 5f9a80af..ec8a6f67 100644
--- a/object/id/errors.go
+++ b/object/id/errors.go
@@ -3,9 +3,9 @@ package id
import "errors"
var (
- // ErrInvalidAlgorithm indicates an unsupported object ID algorithm.
- ErrInvalidAlgorithm = errors.New("objectid: invalid algorithm")
+ // ErrInvalidObjectFormat indicates an unsupported object format.
+ ErrInvalidObjectFormat = errors.New("object/id: invalid object format")
// ErrInvalidObjectID indicates malformed object ID data.
- ErrInvalidObjectID = errors.New("objectid: invalid object id")
+ ErrInvalidObjectID = errors.New("object/id: invalid object id")
)